--[[
    Helper functions
    $Revision: 76359 $
]]--

--[[
Copyright (c) 2008, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local MAJOR_VERSION = "LibHelper-1.0";
local MINOR_VERSION = "$Rev: 76359 $";

local LibHelper, oldminor = LibStub:NewLibrary( MAJOR_VERSION, MINOR_VERSION );
if( not LibHelper ) then
    return;
end

local FlyableZones = nil;
local TooltipScan = nil;

function LibHelper.ItemIsSoulbound( bag, slot )
    if( not TooltipScan ) then
        TooltipScan = CreateFrame( "GameTooltip", "LibHelperTooltipScan", nil, "GameTooltipTemplate" );
    end--if
    
    TooltipScan:SetOwner( WorldFrame, "ANCHOR_NONE" );
    TooltipScan:ClearLines();
    TooltipScan:SetBagItem( bag, slot );
    return( ( getglobal( TooltipScan:GetName() .. "TextLeft2" ):GetText() == ITEM_SOULBOUND ) or
        ( getglobal( TooltipScan:GetName() .. "TextLeft3" ):GetText() == ITEM_SOULBOUND ) or
        ( getglobal( TooltipScan:GetName() .. "TextLeft4" ):GetText() == ITEM_SOULBOUND ) or
        ( getglobal( TooltipScan:GetName() .. "TextLeft2" ):GetText() == ITEM_BIND_QUEST ) or
        ( getglobal( TooltipScan:GetName() .. "TextLeft3" ):GetText() == ITEM_BIND_QUEST ) or
        ( getglobal( TooltipScan:GetName() .. "TextLeft4" ):GetText() == ITEM_BIND_QUEST ) );
end

function LibHelper.GetItemStringFromLink( itemLink )
    local _, _, itemString = itemLink:find( "^|c%x+|H(.+)|h%[.+%]" );

    return itemString;
end--LibHelper.GetItemStringFromLink( itemLink )

function LibHelper.IsInFlyableZone()
    if( not FlyableZones ) then
        FlyableZones = table.concat( { GetMapZones( 3 ) }, "|" );
    end--if
    return FlyableZones:find( GetRealZoneText() ) ~= nil;
end--LibHelper.IsInFlyableZone()

function LibHelper.GetItemIDFromString( itemID )
    return tonumber( itemID:match( "(%d+)" ) );
end--LibHelper.GetItemIDFromString( itemID )

function LibHelper.GetItemIDFromLink( itemLink )
    return LibHelper.GetItemIDFromString( LibHelper.GetItemStringFromLink( itemLink ) );
end--LibHelper.GetItemIDFromLink( itemLink )

function LibHelper.GetItemString( itemID )
    return LibHelper.GetItemStringFromLink( LibHelper.GetItemLink( itemID ) );
end--LibHelper.GetItemString( itemID )

function LibHelper.GetItemLink( itemID )
    local _, itemLink, _, _, _, _, _, _, _, _ = GetItemInfo( itemID );

    return itemLink;
end--LibHelper.GetItemLink( itemID )

function LibHelper.HasPlayerSpell( spell )
    local spellName, _, _, _, _, _, _, _, _ = GetSpellInfo( spell );

    if( spellName ) then
        return GetSpellLink( spell ) == GetSpellLink( spellName );
    end
    return false;
end--LibHelper.PlayerHasSpell( spell )

function LibHelper.CopyTable( to, from )
    for i, v in pairs( from ) do
        if( type( v ) == "table" ) then
            to[i] = {};
            LibHelper.CopyTable( to[i], v );
        else
            to[i] = v;
        end--if
    end--for
end--LibHelper.CopyTable( to, from )

function LibHelper.SimpleCompareTables( table1, table2 )
    if( table1 and table2 ) then
        for i, v in pairs( table1 ) do
            if( type( v ) == "table" ) then
                if( type( table2[i] ) == "table" ) then
                    if( not LibHelper.SimpleCompareTables( v, table2[i] ) ) then
                        return false;
                    end--if
                else
                    return false;
                end--if
            elseif( table2[i] ~= v ) then
                return false;
            end--if
        end--for
    else
        return false;
    end--if
    return true;
end--LibHelper.SimpleCompareTables( table1, table2 )

function LibHelper.CompareTables( table1, table2 )
    return LibHelper.SimpleCompareTables( table1, table2 ) and LibHelper.SimpleCompareTables( table2, table1 );
end--LibHelper.CompareTables( table1, table2 )

function LibHelper.SetButtonImage( button, img )
    if( button.icon ) then
        button.icon:SetTexture( img );
    else
        button:SetNormalTexture( img );
        button:SetHighlightTexture( img );
    end--if
end--LibHelper.SetButtonImage( button, img )

function LibHelper.dprint( addon, msg )
    if( addon.DEBUG ) then
        DEFAULT_CHAT_FRAME:AddMessage( msg, 1.0, 0.0, 0.0 );
    end--if
end--LibHelper.dprint( addon, msg )

